@@ -198,9 +198,7 @@ QList<QAction *> MountIsoAction::actions(const KFileItemListProperties &fileItem
 
     const QString mimeType = fileItemInfos.mimeType();
 
-    if (mimeType != QLatin1String("application/vnd.efi.iso")
-            && mimeType != QLatin1String("application/vnd.efi.img")
-            && mimeType != QLatin1String("application/x-cd-image")
+    if (mimeType != QLatin1String("application/x-cd-image")
             && mimeType != QLatin1String("application/x-raw-disk-image")) {
         return {};
     }
@@ -239,3 +237,5 @@ QList<QAction *> MountIsoAction::actions(const KFileItemListProperties &fileItem
 }
 
 #include "mountisoaction.moc"
+
+#include "moc_mountisoaction.cpp"
